<h1 align="center"> 
  <img src="https://raw.githubusercontent.com/DrSolidDevil/mlr-gd/main/logo.png" width="300">
  <br>
</h1>
Multiple linear regression by gradient descent.
<br><br>
<h4>Disclaimer:</h4>
This code is very early on and my first proper attempt to create a package so things may be a bit weird/not up to standard.

<br>
<br>
<h2>Installation</h2>

To install mlr-gd you can use [pip](https://pip.pypa.io):

```bash
$ python -m pip install mlr-gd
```

Alternativly, you can install it by cloning the [GitHub repository](https://github.com/DrSolidDevil/mlr-gd):
```bash
$ git clone https://github.com/DrSolidDevil/mlr-gd.git
$ cd mlr-gd
$ pip install .
```

<br>

To import the package into your script:  
```python
import melar
```
